package com.example.kosherappstore.adapters

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ArrayAdapter
import android.widget.ImageButton
import android.widget.TextView
import com.example.kosherappstore.R
import com.example.kosherappstore.data.AppInfo

class ManageAppsAdapter(
    context: Context,
    private val appList: List<AppInfo>,
    private val onDeleteClick: (appInfo: AppInfo, position: Int) -> Unit
) : ArrayAdapter<AppInfo>(context, 0, appList) {

    private val inflater: LayoutInflater = LayoutInflater.from(context)

    override fun getView(position: Int, convertView: View?, parent: ViewGroup): View {
        val view: View
        val holder: ViewHolder

        if (convertView == null) {
            view = inflater.inflate(R.layout.list_item_manage_app, parent, false)
            holder = ViewHolder()
            holder.appNameTextView = view.findViewById(R.id.manage_app_name_text_view)
            holder.appPackageNameTextView = view.findViewById(R.id.manage_app_package_name_text_view)
            holder.deleteButton = view.findViewById(R.id.delete_app_from_store_button)
            view.tag = holder
        } else {
            view = convertView
            holder = view.tag as ViewHolder
        }

        val appInfo = getItem(position)
        if (appInfo != null) {
            holder.appNameTextView.text = appInfo.name
            holder.appPackageNameTextView.text = appInfo.packageName

            holder.deleteButton.setOnClickListener {
                onDeleteClick(appInfo, position)
            }

            // D-pad navigation: Allow delete button to be focused when item is focused
            view.onFocusChangeListener = View.OnFocusChangeListener { _, hasFocus ->
                holder.deleteButton.isFocusable = hasFocus
                if(hasFocus && holder.deleteButton.isFocusable){ // if item has focus, try to give focus to button
                    // holder.deleteButton.requestFocus() // This might be too aggressive
                }
            }
            // When item is clicked (Enter on D-pad), give focus to delete button
            view.setOnClickListener {
                holder.deleteButton.requestFocus()
            }

        }
        return view
    }

    private class ViewHolder {
        lateinit var appNameTextView: TextView
        lateinit var appPackageNameTextView: TextView
        lateinit var deleteButton: ImageButton
    }
}